Contributors
============

- Jazkarta, info <at> jazkarta.com
- Witek, witekdev <at> github
- Alec Mitchell, alecpm <at> gmail.com
- Sally Kleinfeldt, skleinfeldt <at> jazkarta.com
- Bert Vanderbauwhede, batlock666 <at> gmail.com
